//
//  PTDisconnectVC.m
//  WirelessPrinter
//
//  Created by midmirror on 16/8/10.
//  Copyright © 2016年 midmirror. All rights reserved.
//

#import "PTDisconnectVC.h"
#import <PrinterSDK/PrinterSDK.h>
#import <FlatUIKit/FlatUIKit.h>
#import "WirelessPrinter-Swift.h"
#import "PTConnectVC.h"
#import "PTIcon.h"

@interface PTDisconnectVC ()

@property(strong,nonatomic,readwrite) FlatMaskView *maskView;
@property(strong,nonatomic,readwrite) NSTimer *timer;

@end

@implementation PTDisconnectVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    [self initMaskView];
    [[PTDispatcher share] scanBluetooth];
    [[PTDispatcher share] whenFindBluetoothAll:^(NSDictionary *printerDict) {
        
        NSMutableAttributedString *attributeText = [[NSMutableAttributedString alloc] initWithString:[NSString stringWithFormat:@"%lu / BLE",(unsigned long)printerDict.count]];
        
        NSUInteger unitLoc = [[attributeText string] rangeOfString:@"/ BLE"].location;
        NSRange unitRange = NSMakeRange(unitLoc, 5);
        NSRange numberRange = NSMakeRange(0,attributeText.length-5);
        [attributeText addAttribute:NSForegroundColorAttributeName value:[UIColor grayColor] range:unitRange];
        [attributeText addAttribute:NSFontAttributeName value:[UIFont fontWithName:font_Thin size:18] range:unitRange];
        [attributeText addAttribute:NSFontAttributeName value:[UIFont fontWithName:font_Thin size:70] range:numberRange];
        [_maskView.titleLabel setAttributedText:attributeText];
    }];
    
    // 10秒后停止扫描蓝牙
    self.timer = [NSTimer scheduledTimerWithTimeInterval:7.0f target:self selector:@selector(stopScanBluetooth:) userInfo:nil repeats:YES];
    [[NSRunLoop mainRunLoop] addTimer:self.timer forMode:NSRunLoopCommonModes];
}

- (void)stopScanBluetooth:(NSTimer *)timer
{
    [timer invalidate];
    [[PTDispatcher share] stopScanBluetooth];
}

- (void)initMaskView {
    
    if ([PTDispatcher share].mode == PTDispatchModeUnconnect) {
        _maskView = [[FlatMaskView alloc] initWithFrame:CGRectMake(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT-TabBar_Height)];
        [_maskView.connectButton addTarget:self action:@selector(popConnectVC) forControlEvents:UIControlEventTouchUpInside];
        [_maskView.secondButton addTarget:self action:@selector(popFlashConnectVC) forControlEvents:UIControlEventTouchUpInside];
        [_maskView setNoticeText:NSLocalizedString(@"Unconencted", nil) shimmer:YES];
        [_maskView setButtonText:NSLocalizedString(@"Scan Connect", nil)];
        [_maskView setSecondButtonText:NSLocalizedString(@"Flash Connect",nil)];
        [_maskView show];
    }
}

/** 当前从父视图控制器移除时，hide mask view */
- (void)removeFromParentViewController
{
    [super removeFromParentViewController];
    [_maskView hideAnimation];
    [self stopScanBluetooth:self.timer];
}

- (void)popFlashConnectVC {
    
    PTFlashConnectVC *flashConnectVC = [[PTFlashConnectVC alloc] init];
    [self presentViewController:flashConnectVC animated:true completion:^{
        
    }];
}

- (void)popConnectVC {
    
    if ([PTDispatcher share].mode == PTDispatchModeUnconnect) {
        
        PTConnectVC *connectVC = [[PTConnectVC alloc] init];
        [self presentViewController:connectVC animated:YES completion:^{
            
        }];
        
    }else {
        
        [[PTDispatcher share] disConnectPrinter];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
