//
//  PTSettingVC.m
//  WirelessPrinter
//
//  Created by midmirror on 16/4/8.
//  Copyright © 2016年 midmirror. All rights reserved.
//

#import "PTSettingVC.h"

@interface PTSettingVC ()<UITableViewDataSource,UITableViewDelegate>

@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) NSArray *textArray;
@property(strong,nonatomic,readwrite) NSMutableArray *detailTextArray;
@property(strong,nonatomic,readwrite) NSArray *colors;

@property(strong,nonatomic,readwrite) FlatPopView *popView;

@end

@implementation PTSettingVC

#pragma mark - Life Cycle

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.view.backgroundColor = [UIColor whiteColor];
    self.title = @"设置";
    
    [self initDataSource];
    [self initTableView];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - init DataSource
- (void)initDataSource {
    
    NSString *copyright = @"Copyright 2016 Xiamen Hanin. All rights reserved";
    
    NSString *version = [FlatToolBox getCurrentVersion];
    _textArray = @[@[@"Version",@"Contact",@"Copyright"],@[@"Theme Color"]];
    
    NSMutableArray *section1 = [[NSMutableArray alloc] initWithArray:@[version,@"ios@prttech.com",copyright]];
    NSMutableArray *section2 = [[NSMutableArray alloc] initWithArray:@[@"Orange"]];
    _detailTextArray = [[NSMutableArray alloc] initWithObjects:section1,section2,nil];
    
    _colors = @[@[@"Orange",@"Blue"]];
}

#pragma mark - init View
- (void)initTableView {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    [self.view addSubview:_tableView];
}

#pragma mark - Touch Response

- (void)popPickerViewAt:(NSIndexPath *)indexPathSelected {
    
    UIColor *headColor = FLAT_COLOR_GRAY;
    
    _popView = [[FlatPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor];
    _popView.titleLabel.text = NSLocalizedString(@"Please Select", nil);
    __block FlatPopView *popView = _popView;
    __block PTSettingVC *settingVC = self;
    [_popView addButtonWithTitle:NSLocalizedString(@"OK", nil) handler:^(FlatPopViewButton *button) {
        
        [popView hideAnimation];        // 隐藏弹出视图
        [settingVC saveSetting:indexPathSelected];
        [settingVC.tableView reloadData];    // 更新 footView 上的表视图
    }];
    
    [_popView show];
    
    FlatPickerKit *picker = [[FlatPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:_colors];
    [_popView.footView addSubview:picker];
}

#pragma mark - Private Method

- (void)saveSetting:(NSIndexPath *)indexPathSelected {
    
    if (indexPathSelected.section == 1) {
        
        FlatToolBox *tool = [[FlatToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[FlatPickerKitModel share].titleArray];
        _detailTextArray[indexPathSelected.section][indexPathSelected.row] = newDetailTitle;
    }
}

#pragma mark - UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return _textArray.count;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    return [_textArray[section] count];
}

- (nullable NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    
    NSArray *titleArray = @[@"About",@"Theme"];
    NSString *titleLocal = NSLocalizedString(titleArray[section], nil);
    
    return titleLocal;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    
    return [FlatFit rowHeight]*0.5;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    
    return 1;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"PTSettingVC";
    UITableViewCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    NSString *textLocal = NSLocalizedString(_textArray[indexPath.section][indexPath.row], nil);
    NSString *detailTextLocal = NSLocalizedString(_detailTextArray[indexPath.section][indexPath.row], nil);
    NSString *detailText = detailTextLocal;
    
    tableCell.textLabel.text = textLocal;
    tableCell.detailTextLabel.text = detailText;
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}

#pragma mark - UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return [FlatFit rowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];//取消选中 cell
    
    if (indexPath.section == 1) {
        
        [self popPickerViewAt:indexPath];
    }
}



@end
