//
//  PTTscBarcodeVC.m
//  WirelessPrinter
//
//  Created by midmirror on 16/3/3.
//  Copyright © 2016年 midmirror. All rights reserved.
//

#import "PTTscBarcodeVC.h"
#import "PTPrinterPort.h"

@interface PTTscBarcodeVC ()

@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) FlatMainView *flatView;
@property(strong,nonatomic,readwrite) FlatPopView *popView;
@property(strong,nonatomic,readwrite) NSArray *barcodeTypeArray;
@property(strong,nonatomic,readwrite) NSArray *barcodeRotationArray;

@property(strong,nonatomic,readwrite) NSArray *commonOption;
@property(strong,nonatomic,readwrite) NSArray *barcodeOption;
@property(strong,nonatomic,readwrite) NSArray *qrcodeOption;

@property(strong,nonatomic,readwrite) NSMutableArray *commonDetailTitle;
@property(strong,nonatomic,readwrite) NSMutableArray *barcodeDetailTitle;
@property(strong,nonatomic,readwrite) NSMutableArray *qrcodeDetailTitle;

@property(strong,nonatomic,readwrite) NSString *barcodeType;
@property(assign,nonatomic,readwrite) NSInteger barcodeReadable;
@property(assign,nonatomic,readwrite) NSInteger barcodeRotation;
@property(assign,nonatomic,readwrite) NSInteger barcodeX;
@property(assign,nonatomic,readwrite) NSInteger barcodeY;
@property(assign,nonatomic,readwrite) NSInteger barcodeHeight;
@property(assign,nonatomic,readwrite) NSInteger barcodeNarrow ;
@property(assign,nonatomic,readwrite) NSInteger barcodeWide;

@property(strong,nonatomic,readwrite) NSString *qrcodeMode;
@property(strong,nonatomic,readwrite) NSString *qrcodeModel;
@property(strong,nonatomic,readwrite) NSString *qrcodeEccLevel;
@property(assign,nonatomic,readwrite) NSInteger qrcodeCellWidth;
@property(strong,nonatomic,readwrite) NSString *qrcodeMask;

@end

@implementation PTTscBarcodeVC

- (void)viewDidLoad {
    [super viewDidLoad];
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"TSC Barcode";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSource];
    [self setupFlatView];
    [self setupFootTable];
}

- (void)viewWillAppear:(BOOL)animated {
    
    self.navigationController.navigationBar.barTintColor = FLAT_COLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];
    [super viewWillAppear:YES];
}

- (void)printAction
{
    NSString *text = _flatView.textView.text;

    PTCommandTSPL *tsc = [[PTCommandTSPL alloc] init];
    
    [tsc setPrintAreaSizeWithWidth:100 Height:10];
    [tsc setCLS];
    
    if ([_barcodeType isEqualToString:@"QRCode"]) { //打印二维码
        
        [tsc printQRcodeWithXPos:_barcodeX
                            YPos:_barcodeY
                        EccLevel:_qrcodeEccLevel
                       CellWidth:_qrcodeCellWidth
                            Mode:_qrcodeMode
                        Rotation:_barcodeRotation
                           Model:_qrcodeModel
                            Mask:_qrcodeMask
                            Text:text];
    }else {
        
        [tsc printBarcodeWithXPos:_barcodeX
                             YPos:_barcodeY
                             Type:_barcodeType
                           Height:_barcodeHeight
                    HumanReadable:_barcodeReadable
                         Rotation:_barcodeRotation
                           Narrow:_barcodeNarrow
                             Wide:_barcodeWide
                       CodeNumber:text];
    }
    
    [tsc printWithSets:1 Copies:1];
    [PTPrinterPort sendData:tsc.cmdData];
}

- (void)setupFlatView {
    
    UIColor *headColor = FLAT_COLOR_BLUE;
    UIColor *footColor = FLAT_COLOR_COULD;
    
    _flatView = [[FlatMainView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    [_flatView.textView setText:@"123456789"];
    
    [_flatView.textView mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.15));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:NSLocalizedString(@"Send To Print", nil) forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(printAction) forControlEvents:UIControlEventTouchUpInside];
    
    CGFloat buttonWidth = [FlatFit getMainButtonWidth];
    CGFloat buttonHeight = [FlatFit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)setupDataSource {
    
    _barcodeType = @"128";
    _barcodeReadable = 0;
    _barcodeRotation = 0;
    _barcodeX = 0;
    _barcodeY = 0;
    _barcodeHeight = 80;
    _barcodeNarrow = 2;
    _barcodeWide = 2;
    
    _qrcodeMode = @"M";
    _qrcodeModel = @"M1";
    _qrcodeEccLevel = @"L";
    _qrcodeCellWidth = 5;
    _qrcodeMask = @"S7";
    
    _barcodeTypeArray = @[@"128",@"128M",@"EAN128",@"25",@"25C",@"39",@"39C",@"39S",@"QRCode"];
    _barcodeRotationArray = @[@"0",@"90",@"180",@"270"];
    
    _commonOption = @[NSLocalizedString(@"Rotation", nil),
                      NSLocalizedString(@"X Coordinate", nil),
                      NSLocalizedString(@"Y Coordinate", nil)];
    _barcodeOption = @[NSLocalizedString(@"Human Readable", nil),
                       NSLocalizedString(@"Narrow", nil),
                       NSLocalizedString(@"Wide", nil),
                       NSLocalizedString(@"Height", nil)];
    _qrcodeOption = @[NSLocalizedString(@"Mode", nil),
                      NSLocalizedString(@"Model", nil),
                      NSLocalizedString(@"ECC Level", nil),
                      NSLocalizedString(@"Cell Width", nil),
                      NSLocalizedString(@"Mask", nil)];
    
    _commonDetailTitle = [[NSMutableArray alloc] initWithObjects:@"0",@"0",@"0",nil];
    _barcodeDetailTitle = [[NSMutableArray alloc] initWithObjects:NSLocalizedString(@"can't be read", nil),@"2",@"2",@"80",nil];
    _qrcodeDetailTitle = [[NSMutableArray alloc] initWithObjects:@"M",@"M1",@"L",@"5",@"S7",nil];
}

- (void)setupFootTable {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    scrollView.scrollEnabled = YES;
    scrollView.contentSize = CGSizeMake(_flatView.footView.bounds.size.width, _flatView.footView.bounds.size.height * 2);
    [_flatView.footView addSubview:scrollView];
    [scrollView addSubview:_tableView];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 3;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    if      (section == 0)  return 1;
    else if (section == 1)  return 3;
    else
    {
        BOOL isQRcode = [_barcodeType isEqualToString:@"QRCode"];
        
        if (isQRcode)   return _qrcodeOption.count;
        else            return _barcodeOption.count;
    }
}

- (nullable NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    
    if      (section == 0)      return NSLocalizedString(@"Type", nil);
    else if (section == 1)      return NSLocalizedString(@"Common Option", nil);
    else                        return NSLocalizedString(@"Barcode Option", nil);
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    
    return [FlatFit rowHeight]*0.5;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    
    return 1;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"TSCBarcodeCell";
    FlatTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[FlatTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    if (indexPath.section == 0) {
        
        tableCell.textLabel.text = NSLocalizedString(@"Type", nil);
        tableCell.detailTextLabel.text = _barcodeType;
    }else if (indexPath.section == 1) {
        
        tableCell.textLabel.text = _commonOption[indexPath.row];
        tableCell.detailTextLabel.text = _commonDetailTitle[indexPath.row];
    }else {
        
        if ([_barcodeType isEqualToString:@"QRCode"]) {
            
            tableCell.textLabel.text = _qrcodeOption[indexPath.row];
            tableCell.detailTextLabel.text = _qrcodeDetailTitle[indexPath.row];
        }else {
            
            tableCell.textLabel.text = _barcodeOption[indexPath.row];
            tableCell.detailTextLabel.text = _barcodeDetailTitle[indexPath.row];
        }
    }
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}


#pragma mark UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [FlatFit rowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    UIColor *headColor = FLAT_COLOR_GRAY;
    
    _popView = [[FlatPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor];
    _popView.titleLabel.text = NSLocalizedString(@"Please Select", nil);
    
    __block FlatPopView *popView = _popView;
    __block PTTscBarcodeVC *tscBarcodeVC = self;
    [_popView addButtonWithTitle:NSLocalizedString(@"OK", nil) handler:^(FlatPopViewButton *button) {
        
        [popView hideAnimation];
        [tscBarcodeVC updateTitleAndParameterAtSection:[NSNumber numberWithInteger:indexPath.section] Row:[NSNumber numberWithInteger:indexPath.row]];
        [tscBarcodeVC.tableView reloadData];
    }];
    
    [_popView show];
    
    FlatToolBox *tool = [[FlatToolBox alloc] init];
    
    NSArray *dataArray;
    NSArray *readable = @[NSLocalizedString(@"can't be read", nil),
                          NSLocalizedString(@"can be read", nil)];
    
    if (indexPath.section == 0) {
        
        dataArray = @[_barcodeTypeArray];
        
    }else if (indexPath.section == 1) {
        
        switch (indexPath.row) {
            case 0: dataArray = @[_barcodeRotationArray];                    break;
            case 1: dataArray = [tool generateNumberArrayWith:@300];    break;
            case 2: dataArray = [tool generateNumberArrayWith:@300];    break;
                
            default:                                                    break;
        }
    }else {
        
        if ([_barcodeType isEqualToString:@"QRCode"]) {
            
            NSArray *mode = @[@"Auto",@"A",@"M"];
            NSArray *model = @[@"M1",@"M2"];
            NSArray *eccLevel = @[@"L",@"M",@"Q",@"H"];
            NSArray *mask = @[@"S0",@"S1",@"S2",@"S3",@"S4",@"S5",@"S6",@"S7",@"S8"];

            switch (indexPath.row) {
                case 0: dataArray = @[mode];       break;
                case 1: dataArray = @[model];      break;
                case 2: dataArray = @[eccLevel];   break;
                case 3: dataArray = [tool generateNumberArrayWith:@10]; break;
                case 4: dataArray = @[mask];       break;
                    
                default:                        break;
            }
            
        }else {
            
            switch (indexPath.row) {
                case 0: dataArray = @[readable];                            break;
                case 1: dataArray = [tool generateNumberArrayWith:@8];      break;
                case 2: dataArray = [tool generateNumberArrayWith:@8];      break;
                case 3: dataArray = [tool generateNumberArrayWith:@255];    break;
                    
                default:                                                    break;
            }
        }
    }
    
    
    FlatPickerKit *picker = [[FlatPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}


- (void)updateTitleAndParameterAtSection:(NSNumber *)section Row:(NSNumber *)row {
    
    if (section) {
        
        int rowInt = [row intValue];
        int sectionInt = [section intValue];
        
        FlatToolBox *tool = [[FlatToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[FlatPickerKitModel share].titleArray];
        
        if (sectionInt == 0) {
            
            _barcodeType = newDetailTitle;
            
        }else if (sectionInt == 1){
            
            newDetailTitle = [tool getFormatNumber:newDetailTitle];
            [_commonDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
            
            switch (rowInt) {
                case 0: _barcodeRotation = newDetailTitle.integerValue;      break;
                case 1: _barcodeX = newDetailTitle.integerValue;             break;
                case 2: _barcodeY = newDetailTitle.integerValue;             break;
                    
                default:
                    break;
            }
            
        }else {
            
            if ([_barcodeType isEqualToString:@"QRCode"]) {
                
                if (rowInt == 3) {
                    newDetailTitle = [tool getFormatNumber:newDetailTitle];
                }
                [_qrcodeDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
                
                switch (rowInt) {
                    case 0: _qrcodeMode = newDetailTitle;      break;
                    case 1: _qrcodeModel = newDetailTitle;     break;
                    case 2: _qrcodeEccLevel = newDetailTitle;   break;
                    case 3: _qrcodeCellWidth = newDetailTitle.integerValue;  break;
                    case 4: _qrcodeMask = newDetailTitle;       break;
                        
                    default:
                        break;
                }
            
            }else {
                
                if (rowInt == 3) {
                    newDetailTitle = [tool getFormatNumber:newDetailTitle];
                }
                [_barcodeDetailTitle replaceObjectAtIndex:rowInt withObject:newDetailTitle];
                switch (rowInt) {
                    case 0: _barcodeReadable = [[FlatPickerKitModel share].rowArray[0] integerValue];;     break;
                    case 1: _barcodeNarrow = newDetailTitle.integerValue;       break;
                    case 2: _barcodeWide = newDetailTitle.integerValue;         break;
                    case 3: _barcodeHeight = newDetailTitle.integerValue;       break;
                        
                    default:
                        break;
                }
            }
        }
    }
}


@end
