//
//  PTTscTextVC.m
//  WirelessPrinter
//
//  Created by midmirror on 16/3/3.
//  Copyright © 2016年 midmirror. All rights reserved.
//

#import "PTTscTextVC.h"
#import "PTPrinterPort.h"

@interface PTTscTextVC ()

@property(strong,nonatomic,readwrite) UITableView *tableView;
@property(strong,nonatomic,readwrite) FlatMainView *flatView;
@property(strong,nonatomic,readwrite) FlatPopView *popView;
@property(strong,nonatomic,readwrite) NSArray *titleArray;
@property(strong,nonatomic,readwrite) NSMutableArray *detailTextArray;
@property(strong,nonatomic,readwrite) NSMutableArray *parameterArray;

@end

@implementation PTTscTextVC

- (void)viewDidLoad {
    [super viewDidLoad];
    
    UILabel *titleLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, 0 , 200, 44)];
    titleLabel.backgroundColor = [UIColor clearColor];
    titleLabel.font = [UIFont systemFontOfSize:20];
    titleLabel.textColor = [UIColor whiteColor];//设置文本颜色
    titleLabel.textAlignment = NSTextAlignmentCenter;
    titleLabel.text = @"TSC Barcode";
    self.navigationItem.titleView = titleLabel;
    
    [self setupDataSource];
    [self setupFlatView];
    [self setupFootTable];
}

- (void)viewWillAppear:(BOOL)animated {
    
    self.navigationController.navigationBar.barTintColor = FLAT_COLOR_BLUE;
    [self.navigationController.navigationBar setTranslucent:NO];
    [super viewWillAppear:YES];
}

- (void)printAction
{
    NSString *text              = _flatView.textView.text;
    NSInteger x                 = [_detailTextArray[0] integerValue];
    NSInteger y                 = [_detailTextArray[1] integerValue];
    NSString *font              = _detailTextArray[2];
    NSInteger rotation          = [_detailTextArray[3] integerValue];
    NSInteger xMultiplication   = [_detailTextArray[4] integerValue];
    NSInteger yMultiplication   = [_detailTextArray[5] integerValue];
    
    
    PTCommandTSPL *tsc = [[PTCommandTSPL alloc] init];
    
    [tsc setPrintAreaSizeWithWidth:100 Height:80];
    [tsc setCLS];
    [tsc printTextWithXPos:x YPos:y Font:font Rotation:rotation XMultiplication:xMultiplication YMultiplication:yMultiplication Text:text];
    [tsc printWithSets:1 Copies:1];
    
    [PTPrinterPort sendData:tsc.cmdData];
}

- (void)setupFlatView {
    
    UIColor *headColor = FLAT_COLOR_BLUE;
    UIColor *footColor = FLAT_COLOR_COULD;
    
    _flatView = [[FlatMainView alloc] initWithWidth:SCREEN_WIDTH Height:SCREEN_HEIGHT splitPercentage:0.4 headColor:headColor footColor:footColor];
    [self.view addSubview:_flatView];
    
    [_flatView.textView setText:@"不同的類可以有相同的方法名。不同類的實例對象執行相同的selector時，會在各自的方法列表中去根據selector去尋找自己對應的IMP。IMP是指向實現函數的指針，通過SEL取得IMP後，我們就獲得了最終要找的實現函數的入口。這個結構體相當於在SEL和IMP之間作了壹個綁定。這樣有了SEL，我們便可以找到對應的IMP，從而調用方法的實現代碼。（在運行時才將SEL和IMP綁定, 動態配置方法）"];
    
    [_flatView.textView mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view.mas_centerX);
        make.top.equalTo(self.view.mas_top).offset(SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(SCREEN_WIDTH * 0.8, SCREEN_WIDTH * 0.15));
    }];
    
    _flatView.mainButton.hidden = NO;
    [_flatView.mainButton setTitle:@"Send To Print" forState:UIControlStateNormal];
    [_flatView.mainButton addTarget:self action:@selector(printAction) forControlEvents:UIControlEventTouchUpInside];
    
    CGFloat buttonWidth = [FlatFit getMainButtonWidth];
    CGFloat buttonHeight = [FlatFit getMainButtonHeight];
    
    [_flatView.mainButton mas_makeConstraints:^(MASConstraintMaker *make) {
        
        make.centerX.equalTo(self.view);
        make.bottom.equalTo(_flatView.headView.mas_bottom).offset(-SCREEN_HEIGHT*0.03);
        make.size.mas_equalTo(CGSizeMake(buttonWidth, buttonHeight));
    }];
}

- (void)setupDataSource {
    
    _titleArray = @[NSLocalizedString(@"X Coordinate", nil),
                    NSLocalizedString(@"Y Coordinate", nil),
                    NSLocalizedString(@"Font", nil),
                    NSLocalizedString(@"Rotation", nil),
                    NSLocalizedString(@"X Multiplication", nil),
                    NSLocalizedString(@"Y Multiplication", nil)];
    _detailTextArray = [[NSMutableArray alloc] initWithObjects:@"0",@"0",@"3",@"0",@"1",@"1", nil];
}

- (void)setupFootTable {
    
    _tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    
    UIScrollView *scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    scrollView.scrollEnabled = YES;
    scrollView.contentSize = CGSizeMake(_flatView.footView.bounds.size.width, _flatView.footView.bounds.size.height * 2);
    [_flatView.footView addSubview:scrollView];
    [scrollView addSubview:_tableView];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView;              // Default is 1 if not implemented
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
{
    return _titleArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
{
    static NSString *iden = @"TSCBarcodeCell";
    FlatTableCell *tableCell = [tableView dequeueReusableCellWithIdentifier:iden];
    if (tableCell == nil) {
        tableCell = [[FlatTableCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:iden];
    }
    
    tableCell.textLabel.text =_titleArray[indexPath.row];
    tableCell.detailTextLabel.text = _detailTextArray[indexPath.row];
    tableCell.detailTextLabel.textColor = [UIColor grayColor];
    
    return tableCell;
}


#pragma mark UITableViewDelegate

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [FlatFit rowHeight];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
{
    UIColor *headColor = FLAT_COLOR_GRAY;
    
    _popView = [[FlatPopView alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4 splitPercentage:0.2 headColor:headColor];
    _popView.titleLabel.text = NSLocalizedString(@"Please Select", nil);
    
    __block FlatPopView *popView = _popView;
    __block PTTscTextVC *tscTextVC = self;
    [_popView addButtonWithTitle:NSLocalizedString(@"OK", nil) handler:^(FlatPopViewButton *button) {
        
        [popView hideAnimation];
        [tscTextVC updateTitleAndParameterAtSection:[NSNumber numberWithInteger:indexPath.section] Row:[NSNumber numberWithInteger:indexPath.row]];
        [tscTextVC.tableView reloadData];
    }];
    
    [_popView show];
    
    FlatToolBox *tool = [[FlatToolBox alloc] init];
    
    NSArray *dataArray;
    
    NSArray *font = @[@"0",@"1",@"2",@"3",@"4",@"5",@"6",@"7",@"8",@"ROMAN.TTF"];
    
    switch (indexPath.row) {
        case 0: dataArray = [tool generateNumberArrayWith:@255];     break;
        case 1: dataArray = [tool generateNumberArrayWith:@255];     break;
        case 2: dataArray = @[font];                                 break;
        case 3: dataArray = @[@[@"0",@"90",@"180",@"270"]];          break;
        case 4: dataArray = [tool generateNumberArrayWith:@10];      break;
        case 5: dataArray = [tool generateNumberArrayWith:@10];      break;
            
        default:                        break;
    }
    
    FlatPickerKit *picker = [[FlatPickerKit alloc] initWithWidth:SCREEN_WIDTH*0.6 Height:SCREEN_HEIGHT*0.4*0.8 withDataSource:dataArray];
    [_popView.footView addSubview:picker];
}


- (void)updateTitleAndParameterAtSection:(NSNumber *)section Row:(NSNumber *)row {
    
    if (section) {
        
        int rowInt = [row intValue];
        
        FlatToolBox *tool = [[FlatToolBox alloc] init];
        NSString *newDetailTitle = [tool pieceStringWithArray:[FlatPickerKitModel share].titleArray];
        
        if ((rowInt < 2) || (rowInt >3)) {
            newDetailTitle = [tool getFormatNumber:newDetailTitle];
        }
        [_detailTextArray replaceObjectAtIndex:rowInt withObject:newDetailTitle];
    }
}

@end
