//
//  SwiftDefine.swift
//  WirelessPrinter
//
//  Created by midmirror on 16/5/3.
//  Copyright © 2016年 midmirror. All rights reserved.
//

import Foundation
import UIKit


public let ScreenWidth = UIScreen.main.bounds.size.width
public let ScreenHeight = UIScreen.main.bounds.size.height
public let ScreenSize = ScreenWidth * ScreenHeight
public let ScreenScale = UIScreen.main.scale
public let ScreenResolution = ScreenWidth*ScreenScale*ScreenHeight*ScreenScale
public let TabBarHeight = 49.0
public let NavigationHeight = 44.0
public let StatusHeight = 20.0

public let flatColorGreen = UIColor.init(red: 94/255, green: 194/255, blue: 32/255, alpha: 1.0)
public let flatColorBlue = UIColor.init(red: 76/255, green: 172/255, blue: 239/255, alpha: 1.0)
public let flatColorBlueLight = UIColor.init(red: 0.388, green: 0.675, blue: 0.937, alpha: 1.0)
public let flatColorBlueSea = UIColor.init(red: 0, green: 122/255, blue: 1, alpha: 1.0)
public let flatColorGray = UIColor.init(red: 145/255, green: 145/255, blue: 145/255, alpha: 1.0)
public let flatColorGrayMi = UIColor.init(red: 103/255, green: 130/255, blue: 141/255, alpha: 1.0)
public let flatColorRed = UIColor.init(red: 231/255, green: 76/255, blue: 60/255, alpha: 1.0)
public let flatColorRedDark = UIColor.init(red: 192/255, green: 57/255, blue: 43/255, alpha: 1.0)
public let flatColorCyan = UIColor.init(red: 26/255, green: 188/255, blue: 156/255, alpha: 1.0)
public let flatColorCyanDark = UIColor.init(red: 22/255, green: 160/255, blue: 133/255, alpha: 1.0)
public let flatColorCould = UIColor.init(red: 236/255, green: 240/255, blue: 241/255, alpha: 1.0)
public let flatColorCouldLight = UIColor.init(red: 241/255, green: 241/255, blue: 245/255, alpha: 1.0)
public let flatColorCouldMiddle = UIColor.init(red: 150/255, green: 150/255, blue: 150/255, alpha: 1.0)
public let flatColorDarkBlue = UIColor.init(red: 52/255, green: 73/255, blue: 94/255, alpha: 1.0)
public let flatColorDarkblueDark = UIColor.init(red: 44/255, green: 62/255, blue: 80/255, alpha: 1.0)
public let flatColorOrange = UIColor.init(red: 1, green: 135/255, blue: 7/255, alpha: 1.0)

public let sandboxPathDocuments = NSSearchPathForDirectoriesInDomains(FileManager.SearchPathDirectory.documentDirectory, FileManager.SearchPathDomainMask.userDomainMask, true).last!
public let sandboxPathCaches   = NSSearchPathForDirectoriesInDomains(FileManager.SearchPathDirectory.cachesDirectory, FileManager.SearchPathDomainMask.userDomainMask, true).last!

public let A4InchWidth: CGFloat = 21/2.54
public let A4InchHeight: CGFloat = 29.7/2.54
public let mmPerInch: CGFloat = 25.4

public let font_light = "HelveticaNeue-Light"
public let font_Thin  = "HelveticaNeue-Thin"

public func RGBA (_ r:CGFloat, g:CGFloat, b:CGFloat, a:CGFloat) -> UIColor
{
    return UIColor(red: r/255.0, green: g/255.0, blue: b/255.0, alpha: a)
}

/** 在200 DPI 的情况下，画布的范围 */
public func RectDPI200() -> CGRect {
    
    return CGRect(x: 0, y: 0, width: 200 * A4InchWidth, height: 200 * A4InchHeight)
}

public func RectDPI300() -> CGRect {
    
    return CGRect(x: 0, y: 0, width: 300 * A4InchWidth, height: 300 * A4InchHeight)
}

public func SizeDPI200() -> CGSize {
    
    return CGSize(width: 200 * A4InchWidth, height: 200 * A4InchHeight)
}

public func SizeDPI300() -> CGSize {
    
    return CGSize(width: 300 * A4InchWidth, height: 300 * A4InchHeight)
}

/** 生成随机颜色 */
public func randomColor() -> UIColor {
    
    let randomColor = UIColor.init(red: randomColorValue(), green: randomColorValue(), blue: randomColorValue(), alpha: 1.0)
    
    return randomColor
}

/** 生成随机颜色数值 */
public func randomColorValue() -> CGFloat {
    
    return CGFloat(arc4random_uniform(256))/255.0
}

/** 按比例缩放 rect */
public func scaleRect(_ rect: CGRect, n: CGFloat) -> CGRect {
    
    let newRect = CGRect(x: (rect.size.width - rect.size.width * n)/2.0, y: (rect.size.height - rect.size.height * n)/2.0, width: rect.size.width * n, height: rect.size.height * n)
    return newRect
}

public enum DeviceResolution: CGFloat {
    
    case iPhone     = 153600        // 480*320
    case iPhone4    = 614400.0      // 960*640
    case iPhone5    = 727040.0      // 1136*640
    case iPhone6    = 1000500.0     // 1334*750
    case iPhone6p   = 2073600.0     // 1920*1080
    case iPad       = 786432.0      // 1024*768
    case iPadRetina = 3145728.0     // 2048*1536
    case iPadPro    = 5595136.0     // 2732*2048
}

public func isPointInRect(_ point: CGPoint, rect: CGRect) -> Bool {
    
    return (point.x >= rect.origin.x &&
            point.x <= (rect.origin.x + rect.size.width) &&
            point.y >= rect.origin.y &&
            point.y <= (rect.origin.y + rect.size.height));
}
